@@ -2,6 +2,6 @@
 # Configuration file for using the xslt library
 #
 XSLT_LIBDIR="-L/usr/local/lib"
-XSLT_LIBS="-lxslt -L/usr/local/lib -lxml2 -lz -lm -lm"
+XSLT_LIBS="-lxslt  -L/usr/local/lib -lxml2 -lz -lpthread -L/usr/local/lib -liconv -lm -lm"
 XSLT_INCLUDEDIR="-I/usr/local/include"
-MODULE_VERSION="xslt-0.7.0"
+MODULE_VERSION="xslt-1.0.22"
